@@ -9,7 +9,7 @@ use strict;
 # This module is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
-# Written by David Huggins-Daines <dhd@cepstral.com>
+# Written by David Huggins-Daines <dhuggins@cs.cmu.edu>
 
 package Speech::Recognizer::SPX::Server;
 use Speech::Recognizer::SPX qw(:fbs :uttproc $SPHINXDIR);
@@ -335,6 +335,6 @@ perl(1), L<Speech::Recognizer::SPX>.
 
 =head1 AUTHOR
 
-David Huggins-Daines <dhd@cepstral.com>
+David Huggins-Daines <dhuggins@cs.cmu.edu>
 
 =cut
